package com.capitalware.ufmsm.mq.objects;

import java.io.File;

/**
 * This class holds the MQ information.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.0
 * @license Apache 2 License
 */
public class MQObject
{
   public int                          refreshRate = 60;
   public String                       qMgrName = null;
   public QueueObject                  qObject = null;
   public String                       hostname = null;
   public String                       channelName = null;
   public int                          port = -1;
   //
   public String                       userID = System.getProperty("user.name");
   public String                       password = null;
   //
   public String                       securityExit = null;
   public String                       securityExitPath = null;
   public String                       securityExitData = null;
   //
   public String                       cipherSuiteName = null;
   public String                       distinguishedName = null;
   public String                       trustedStore = null;
   public String                       trustedStorePasswd = null;
   public String                       keyStore = null;
   public String                       keyStorePasswd = null;
   public String                       ldapServer = null;
   public int                          ldapServerPort = -1;
   //
   public String                       CCDTFile = null;
   public String                       mqXmlFile = null;

   /*
    * The constructor
    */
   public MQObject()
   {
      super();
   }

   /**
    * Verify the values in the MQOject
    */
   public void checkQM()
   {
      if ( ("".equals(qMgrName)) || (qMgrName == null) )
         throw new IllegalArgumentException("Missing a required XML tag: QMgrName within MQ");

      if ( ("".equals(qObject)) || (qObject == null) )
         throw new IllegalArgumentException("Missing a required XML tag: QueueName within MQ");
      
      if ( (userID == null) && (password != null) )
         throw new IllegalArgumentException("Cannot have a Password without a UserID: UserID within MQ");

      if ((hostname != null) || (channelName != null))
      {
         if (hostname == null)
            throw new IllegalArgumentException("Missing the XML tag: Hostname within UFM_MQ.");
         if (channelName == null)
            throw new IllegalArgumentException("Missing the XML tag: ChannelName within UFM_MQ.");

         if (CCDTFile != null)
            throw new IllegalArgumentException("The user cannot specify both channelname/hostname/port and CCDTFile.  Please specify only one method of connecting to the remote queue manager.");
      }
      else if (CCDTFile != null)
      {
         boolean exists = (new File(CCDTFile)).exists();
         if ( !(exists) )
            throw new IllegalArgumentException("Error: The CCDT file does not exists : " + CCDTFile);
      }
   }
}
